# Resolve Merge Conflicts

Review:
- Git status
- the recent/relevant Git history
- planning docs for any relevant pieces of work
- the details of the merge conflict itself
- relevant code & docs, starting with relevant planning documents

Look for a way to preserve the best of both worlds.

Do you feel confident about how to resolve the merge conflict? Ask if you have questions.

Ultrathink.

Make a proposal. Don't make changes yet.
